@@ -5,8 +5,8 @@ from django.http import JsonResponse
 from django.utils.deprecation import MiddlewareMixin
 from jwt import ExpiredSignatureError
 
-from django_jwt.jwt import verifier
 from django_jwt.user import UserHandler
+from django_jwt.utils import oidc_handler
 
 log = getLogger(__name__)
 
@@ -22,12 +22,15 @@ class JWTAuthMiddleware(MiddlewareMixin):
         if not auth_header.startswith("Bearer "):
             return
 
-        token = auth_header[7:]
+        # auth part
+        raw_token = auth_header[7:]
         try:
-            info = verifier.verify_token(token)
+            info = oidc_handler.decode_token(raw_token)
+            request.user = request._cached_user = UserHandler(info, request, raw_token).get_user()
         except ExpiredSignatureError:
             return JsonResponse(status=HTTPStatus.UNAUTHORIZED.value, data={"detail": "expired token"})
+        except UnicodeDecodeError as exc:
+            log.warning(f"UnicodeDecodeError: {exc}")
         except Exception as exc:
-            log.error("Unexpected error", exc)
+            log.warning(f"Unexpected error: {exc}")
             return
-        request.user = request._cached_user = UserHandler(info, request).get_user()
